#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library
import json

# import interfaces
from pyams_skin.layer import IPyAMSLayer

# import packages
from pyams_form.widget import widgettemplate_config
from z3c.form.browser.orderedselect import OrderedSelectWidget
from z3c.form.widget import FieldWidget


@widgettemplate_config(mode='input', template='templates/widget-input.pt', layer=IPyAMSLayer)
@widgettemplate_config(mode='display', template='templates/widget-display.pt', layer=IPyAMSLayer)
class SingleLinkLinkSelectWidget(OrderedSelectWidget):
    """Single Link link select widget"""

    @property
    def values_data(self):
        result = sorted([{'id': entry['value'], 'text': entry['content']} for entry in self.items],
                        key=lambda x: x['text'])
        return json.dumps(result)

    @property
    def values_map(self):
        result = {}
        [result.update({entry['value']: entry['content']}) for entry in self.selectedItems]
        return json.dumps(result)


def SingleLinkLinkSelectFieldWidget(field, request):
    """Single link link select widget factory"""
    return FieldWidget(field, SingleLinkLinkSelectWidget(request))


@widgettemplate_config(mode='input', template='templates/widget-list-input.pt', layer=IPyAMSLayer)
@widgettemplate_config(mode='display', template='templates/widget-list-display.pt', layer=IPyAMSLayer)
class LinkLinksSelectWidget(OrderedSelectWidget):
    """Multiple inks links select widget"""

    @property
    def values_map(self):
        result = {}
        [result.update({entry['value']: entry['content']}) for entry in self.selectedItems]
        return json.dumps(result)


def LinkLinksSelectFieldWidget(field, request):
    """Links links select widget factory"""
    return FieldWidget(field, LinkLinksSelectWidget(request))
