#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library

# import interfaces
from pyams_content.component.paragraph.interfaces import IParagraphContainerTarget, IParagraphContainer, \
    IParagraphSummary
from pyams_content.shared.common.interfaces.zmi import IInnerSummaryView
from pyams_form.interfaces.form import IInnerTabForm
from pyams_i18n.interfaces import II18nManager
from pyams_skin.layer import IPyAMSLayer

# import packages
from pyams_content.shared.common.zmi.summary import SharedContentSummaryForm
from pyams_pagelet.pagelet import pagelet_config
from pyams_template.template import template_config
from pyams_utils.adapter import adapter_config
from pyams_utils.interfaces import VIEW_SYSTEM_PERMISSION
from pyams_zmi.form import InnerAdminDisplayForm
from z3c.form import field
from zope.interface import implementer, Interface

from pyams_content import _


@adapter_config(name='paragraphs-summary',
                context=(IParagraphContainerTarget, IPyAMSLayer, SharedContentSummaryForm),
                provides=IInnerTabForm)
class ParagraphsContainerSummaryForm(InnerAdminDisplayForm):
    """Paragraphs container summary"""

    weight = 20
    tab_label = _("Quick preview")
    tab_target = 'paragraphs-summary.html'

    fields = field.Fields(Interface)


@pagelet_config(name='paragraphs-summary.html', context=IParagraphContainerTarget, layer=IPyAMSLayer,
                permission=VIEW_SYSTEM_PERMISSION)
@template_config(template='templates/summary.pt', layer=IPyAMSLayer)
@implementer(IInnerSummaryView)
class ParagraphsContainerSummaryView(object):
    """Paragraphs container summary view"""

    def __init__(self, context, request):
        super(ParagraphsContainerSummaryView, self).__init__(context, request)
        self.paragraphs = IParagraphContainer(self.context)
        self.languages = II18nManager(self.context).get_languages()

    def render_paragraph(self, paragraph, language=None):
        renderer = self.request.registry.queryMultiAdapter((paragraph, self.request), IParagraphSummary)
        if renderer is not None:
            renderer.language = language
            renderer.update()
            return renderer.render()
