(function($, globals) {

	"use strict";

	var MyAMS = globals.MyAMS;

	var PyAMS_content = {

		/**
		 * TinyMCE editor configuration
		 */
		TinyMCE: {

			initEditor: function(settings) {
				settings.image_list = PyAMS_content.TinyMCE.getImagesList;
				settings.link_list = PyAMS_content.TinyMCE.getLinksList;
				return settings;
			},

			getImagesList: function(callback) {
				return MyAMS.ajax.post('get-images-list.json', {}, callback);
			},

			getLinksList: function(callback) {
				return MyAMS.ajax.post('get-links-list.json', {}, callback);
			}
		},

		/**
		 * User profile management
		 */
		profile: {

			switchFavorite: function() {
				var star = $(this);
				var oid = star.data('sequence-oid');
				MyAMS.ajax.post('switch-user-favorite.json',
								{oid: oid},
								function(result, status) {
									if (result.favorite) {
										star.removeClass('fa-star-o')
											.addClass('fa-star');
									} else {
										star.removeClass('fa-star')
											.addClass('fa-star-o');
									}
								});
			}
		},

		/**
		 * External files management
		 */
		extfiles: {

			refresh: function(options) {
				if (typeof(options) === 'string') {
					options = JSON.parse(options);
				}
				var select = $('select[name="form.widgets.files:list"]');
				var plugin = select.data('select2');
				$('<option></option>').attr('value', options.new_file.id)
									  .attr('selected', 'selected')
									  .text(options.new_file.text)
									  .appendTo(select);
				var data = select.select2('data');
				data.push(options.new_file);
				select.select2('data', data);
				plugin.results.empty();
				plugin.opts.populateResults.call(plugin, plugin.results, options.files, {term: ''});
			},

			refreshContainer: function(changes) {
				var para = $('tr[data-ams-element-name="' + changes.object_name + '"]');
				var counter = $('span.count', $('div.action.extfiles', para));
				if (changes.nb_files > 0) {
					counter.text('(' + changes.nb_files + ')');
				} else {
					counter.text('');
				}
			}
		},


		/**
		 * Links management
		 */
		links: {

			init: function() {

				function initElements(data, status) {
					var plugin = select.data('select2');
					plugin.results.empty();
					plugin.opts.populateResults.call(plugin, plugin.results, data, {term: ''});
				}

				var select = $(this);
				MyAMS.ajax.post('get-links.json', {
					keyFieldName: 'id',
					valueFieldName: 'text'
				}, initElements);
			},

			refresh: function(options) {
				if (typeof(options) === 'string') {
					options = JSON.parse(options);
				}
				var select = $('input[name="form.widgets.link"], select[name="form.widgets.links:list"]');
				var plugin = select.data('select2');
				if (select.attr('type') === 'select') {
					$('<option></option>').attr('value', options.new_link.id)
										  .attr('selected', 'selected')
										  .text(options.new_link.text)
										  .appendTo(select);
				}
				var data;
				if (select.prop('multiple')) {
					data = select.select2('data');
					data.push(options.new_link);
					select.select2('data', data);
					plugin.results.empty();
					plugin.opts.populateResults.call(plugin, plugin.results, options.links, {term: ''});
				} else {
					select.select2('data', [options.new_link]);
					plugin.results.empty();
					plugin.opts.populateResults.call(plugin, plugin.results, options.links, {term: ''});
					select.val(options.new_link.id);
				}
			},

			refreshContainer: function(changes) {
				var para = $('tr[data-ams-element-name="' + changes.object_name + '"]');
				var counter = $('span.count', $('div.action.links', para));
				if (changes.nb_links > 0) {
					counter.text('(' + changes.nb_links + ')');
				} else {
					counter.text('');
				}
			}
		},


		/**
		 * Galleries management
		 */
		galleries: {

			refresh: function(options) {
				if (typeof(options) === 'string') {
					options = JSON.parse(options);
				}
				var select = $('select[name="form.widgets.galleries:list"]');
				var plugin = select.data('select2');
				$('<option></option>').attr('value', options.new_gallery.id)
									  .attr('selected', 'selected')
									  .text(options.new_gallery.text)
									  .appendTo(select);
				var data = select.select2('data');
				data.push(options.new_gallery);
				select.select2('data', data);
				plugin.results.empty();
				plugin.opts.populateResults.call(plugin, plugin.results, options.galleries, {term: ''});
			},

			setOrder: function(event, ui) {
				if (ui && ui.item.hasClass('already-dropped')) {
					return;
				}
				var gallery = ui.item.parents('.gallery');
				var ids = $('.image', gallery).listattr('data-ams-element-name');
				MyAMS.ajax.post(gallery.data('ams-location') + '/set-images-order.json',
								{images: JSON.stringify(ids)});
			},

			removeFile: function(element) {
				return function() {
					var link = $(this);
					MyAMS.skin.bigBox({
						title: MyAMS.i18n.WARNING,
						content: '<i class="text-danger fa fa-2x fa-bell shake animated"></i>&nbsp; ' + MyAMS.i18n.DELETE_WARNING,
						buttons: MyAMS.i18n.BTN_OK_CANCEL
					}, function(button) {
						if (button === MyAMS.i18n.BTN_OK) {
							var gallery = link.parents('.gallery');
							var location = gallery.data('ams-location');
							var image = link.parents('.image');
							var object_name = image.data('ams-element-name');
							MyAMS.ajax.post(location + '/delete-element.json',
											{object_name: object_name},
											function(result, status) {
												image.remove();
											});
						}
					});
				};
			},

			refreshContainer: function(changes) {
				var para = $('tr[data-ams-element-name="' + changes.object_name + '"]');
				var counter = $('span.count', $('div.action.galleries', para));
				if (changes.nb_galleries > 0) {
					counter.text('(' + changes.nb_galleries + ')');
				} else {
					counter.text('');
				}
			}
		},


		/**
		 * Image map management
		 */
		imgmap: {

			init: function() {
				var image = $(this);
				MyAMS.ajax.check($.fn.canvasAreaDraw,
								 '/--static--/pyams_content/js/jquery-canvasAreaDraw' + MyAMS.devext + '.js',
								 function() {
									image.canvasAreaDraw({imageUrl: image.data('ams-image-url')});
								 });
			},

			initSummary: function() {
				var image = $(this);
				MyAMS.ajax.check($.fn.mapster,
								 '/--static--/pyams_content/js/jquery-imagemapster-1.2.10' + MyAMS.devext + '.js',
								 function() {
									image.mapster({
										fillColor: 'ff0000',
										fillOpacity: 0.35,
										selected: true,
										highlight: true,
										staticState: true
									});
								 });
			}
		},


		/**
		 * Paragraphs management
		 */
		paragraphs: {

			switchVisibility: function(element) {
				return function() {
					var source = $(this);
					var para = source.parents('tr');
					var container = para.parents('table');
					MyAMS.ajax.post(container.data('ams-location') + '/set-paragraph-visibility.json',
									{object_name: para.data('ams-element-name')},
									function(result, status) {
										if (result.visible) {
											$('i', source).attr('class', 'fa fa-fw fa-eye');
										} else {
											$('i', source).attr('class', 'fa fa-fw fa-eye-slash text-danger');
										}
									});
				};
			},

			refreshParagraph: function(changes) {
				var container = $('table[id="paragraphs_list"]');
				var para = $('tr[data-ams-element-name="' + changes.object_name + '"]', container);
				if (changes.visible) {
					$('i', $('td.switcher', para)).removeClass('fa-eye-slash text-danger')
												  .addClass('fa-eye');
				} else {
					$('i', $('td.switcher', para)).removeClass('fa-eye')
												  .addClass('fa-eye-slash text-danger');
				}
				$('span.title', para).text(changes.title || '--');
			},

			switchEditor: function(element) {
				var source = $(this);
				var switcher = $('i', source);
				var td = source.parents('td');
				var editor = $('.editor', td);
				var para = source.parents('tr');
				if (switcher.hasClass('fa-plus-square-o')) {
					var container = para.parents('table');
					editor.html('<h1 class="loading"><i class="fa fa-2x fa-gear fa-spin"></i></h1>');
					MyAMS.ajax.post(container.data('ams-location') + '/get-paragraph-editor.json',
									{object_name: para.data('ams-element-name')},
									function(result) {
										editor.html(result);
										if (result) {
											MyAMS.initContent(editor);
											switcher.removeClass('fa-plus-square-o')
													.addClass('fa-minus-square-o');
											para.data('ams-disabled-handlers', true);
										}
									});
				} else {
					MyAMS.skin.cleanContainer(editor);
					editor.empty();
					switcher.removeClass('fa-minus-square-o')
							.addClass('fa-plus-square-o');
					para.removeData('ams-disabled-handlers');
				}
			},

			switchAllEditors: function(element) {
				var source = $(this);
				var switcher = $('i', source);
				var container = source.parents('table');
				if (switcher.hasClass('fa-plus-square-o')) {
					switcher.removeClass('fa-plus-square-o')
							.addClass('fa-cog fa-spin');
					MyAMS.ajax.post(container.data('ams-location') + '/get-paragraphs-editors.json',
									{},
									function(result) {
										for (var para_id in result) {
											if (!result.hasOwnProperty(para_id)) {
												continue;
											}
											var para = $('tr[data-ams-element-name="' + para_id + '"]', container);
											var editor = $('.editor', para);
											if (editor.is(':empty')) {
												editor.html(result[para_id]);
												MyAMS.initContent(editor);
											}
											$('.fa-plus-square-o', para).removeClass('fa-plus-square-o')
																		.addClass('fa-minus-square-o');
											para.data('ams-disabled-handlers', true);
										}
										if (!$('i.fa-plus-square-o', $('tbody', container)).exists()) {
											switcher.removeClass('fa-cog fa-spin')
													.addClass('fa-minus-square-o');
										}
									});
				} else {
					$('.editor', container).each(function() {
						MyAMS.skin.cleanContainer($(this));
						$(this).empty();
					});
					$('.fa-minus-square-o', container).removeClass('fa-minus-square-o')
													  .addClass('fa-plus-square-o');
					$('tr', container).removeData('ams-disabled-handlers');
				}
			}
		},


		/**
		 * Themes management
		 */
		themes: {

			initExtracts: function(element) {
				var thesaurus = $('select[name="form.widgets.thesaurus_name:list"]', element);
				var thesaurus_name = thesaurus.val();
				var extract = $('select[name="form.widgets.extract_name:list"]', element);
				var extract_name = extract.val();
				if (thesaurus_name) {
					MyAMS.jsonrpc.post('getExtracts',
									   {thesaurus_name: thesaurus_name},
									   {url: '/api/thesaurus/json'},
									   function(data) {
											extract.empty();
											$(data.result).each(function() {
												$('<option></option>').attr('value', this.id)
																	  .attr('selected', this.id === extract_name)
																	  .text(this.text)
																	  .appendTo(extract);
											});
									   });
				}
				extract.attr('data-ams-events-handlers', '{"select2-open": "PyAMS_content.themes.getExtracts"}');
			},

			getExtracts: function(event) {
				var select = $(event.currentTarget);
				var form = select.parents('form');
				var thesaurus_name = $('select[name="form.widgets.thesaurus_name:list"]', form).val();
				if (thesaurus_name) {
					MyAMS.jsonrpc.post('getExtracts',
									   {thesaurus_name: thesaurus_name},
									   {url: '/api/thesaurus/json'},
									   function(data) {
											var extract = $('select[name="form.widgets.extract_name:list"]', form);
											var plugin = extract.data('select2');
											plugin.results.empty();
											plugin.opts.populateResults.call(plugin, plugin.results, data.result,
																			 {term: ''});
									   });
				}
			}
		},


		/**
		 * Review comments management
		 */
		review: {

			timer: null,
			timer_duration: {
				general: 30000,
				chat: 5000
			},

			initComments: function(element) {
				var chat = $('.chat-body', element);
				chat.animate({scrollTop: chat[0].scrollHeight}, 1000);
				clearInterval(PyAMS_content.review.timer);
				PyAMS_content.review.timer = setInterval(PyAMS_content.review.updateComments,
														 PyAMS_content.review.timer_duration.chat);
				MyAMS.skin.registerCleanCallback(PyAMS_content.review.cleanCommentsCallback);
			},

			cleanCommentsCallback: function() {
				clearInterval(PyAMS_content.review.timer);
				PyAMS_content.review.timer = setInterval(PyAMS_content.review.updateComments,
														 PyAMS_content.review.timer_duration.general);
			},

			updateComments: function() {
				var badge = $('.badge', 'nav a[href="#review-comments.html"]'),
					count;
				var chat = $('.chat-body', '.widget-body');
				if (chat.exists()) {
					count = $('.message', chat).length;
				} else {
					count = parseInt(badge.text());
				}
				MyAMS.ajax.post('get-last-review-comments.json', {count: count}, function(result) {
					if (chat.exists()) {
						badge.removeClass('bg-color-danger')
							 .addClass('bg-color-info');
					}
					if (count !== result.count) {
						badge.text(result.count).removeClass('hidden');
						if (chat.exists()) {
							$('.messages', chat).append(result.content);
							chat.animate({scrollTop: chat[0].scrollHeight}, 1000);
						}
						if (!chat.exists()) {
							badge.removeClass('bg-color-info')
								 .addClass('bg-color-danger')
								 .animate({'padding': '3px 12px 2px',
										   'margin-right': '9px'}, 'slow', function() {
									$(this).animate({'padding': '3px 6px 2px',
													 'margin-right': '15px'}, 'slow');
								 });
						}
					}
				});
			},

			initCommentData: function(veto) {
				var chat = $('.chat-body', '.widget-body');
				return {count: $('.message', chat).length};
			},

			addCommentCallback: function(options) {
				var form = $(this);
				var widget = form.parents('.widget-body');
				$('.messages', widget).append(options.content);
				$('textarea[name="comment"]', form).val('');
				var chat = $('.chat-body', widget);
				chat.animate({scrollTop: chat[0].scrollHeight}, 1000);
				$('.badge', 'nav a[href="#review-comments.html"]').text(options.count).removeClass('hidden');
			}
		}
	};

	globals.PyAMS_content = PyAMS_content;

	$(globals.document).on('PyAMS_content.changed_item', function(event, settings) {
		switch (settings.object_type) {
			case 'paragraph':
				PyAMS_content.paragraphs.refreshParagraph(settings);
				break;
			case 'extfiles_container':
				PyAMS_content.extfiles.refreshContainer(settings);
				break;
			case 'links_container':
				PyAMS_content.links.refreshContainer(settings);
				break;
			case 'galleries_container':
				PyAMS_content.galleries.refreshContainer(settings);
				break;
			case 'review_comments':
				PyAMS_content.review.updateComments();
				break;
		}
	});

	var badge = $('.badge', 'nav a[href="#review-comments.html"]');
	if (badge.exists()) {
		PyAMS_content.review.timer = setInterval(PyAMS_content.review.updateComments,
												 PyAMS_content.review.timer_duration.general);
	}

})(jQuery, this);
